@@ -116,7 +116,7 @@ get_colid <- function(sciname, ask = TRUE, verbose = TRUE, rows = NA,
   fun <- function(sciname, ask, verbose, rows, ...) {
     mssg(verbose, "\nRetrieving data for taxon '", sciname, "'\n")
     df <- col_search(name = sciname, response = "full", ...)[[1]]
-    df <- df[, names(df) %in% c("name","rank","id","name_status","kingdom","family")]
+    df <- df[, names(df) %in% c("name","rank","id","name_status","kingdom","family","acc_name")]
     df <- sub_rows(df, rows)
 
     rank_taken <- NA
@@ -247,9 +247,7 @@ make_colid <- function(x, check=TRUE) make_generic(x, 'http://www.catalogueoflif
 check_colid <- function(x){
   url <- "http://www.catalogueoflife.org/col/details/species/id/"
   res <- GET(paste0(url, x))
-  tt <- content(res)
-  tryid <- xpathSApply(tt, '//p', xmlValue)
-  identical(list(), tryid)
+  !grepl("Species not found", res)
 }
 
 #' @export
