@@ -13,7 +13,7 @@ test_that("gbif_downstream works", {
 })
 
 test_that("gbif_downstream works, more egs", {
-  bb <- gbif_downstream(key = 1878, "Family")
+  bb <- gbif_downstream(key = 1227, "Family")
 
   expect_is(bb, "data.frame")
   expect_is(bb$canonicalname, "character")
@@ -24,7 +24,7 @@ test_that("gbif_downstream works, more egs", {
 })
 
 test_that("gbif_downstream intermediate param works", {
-  cc <- gbif_downstream(key = 1334757, downto = "Species", intermediate = TRUE)
+  cc <- gbif_downstream(key = 198, downto = "genus", intermediate = TRUE)
 
   expect_is(cc, "list")
   expect_is(cc$target, "data.frame")
@@ -34,7 +34,7 @@ test_that("gbif_downstream intermediate param works", {
   expect_is(cc$target$rank, "character")
   expect_is(cc$target$key, "integer")
 
-  expect_equal(unique(cc$target$rank), "species")
+  expect_equal(unique(cc$target$rank), "genus")
 })
 
 test_that("gbif_downstream fails well", {
